Method: Docker::Image#insert_local
- Defined in:
- lib/docker/image.rb
#insert_local(opts = {}) ⇒ Object
Given a path of a local file and the path it should be inserted, creates a new Image that has that file.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/docker/image.rb', line 53 def insert_local(opts = {}) local_paths = opts.delete('localPath') output_path = opts.delete('outputPath') local_paths = [ local_paths ] unless local_paths.is_a?(Array) file_hash = Docker::Util.file_hash_from_paths(local_paths) file_hash['Dockerfile'] = dockerfile_for(file_hash, output_path) tar = Docker::Util.create_tar(file_hash) body = connection.post('/build', opts, :body => tar) self.class.send(:new, connection, 'id' => Docker::Util.extract_id(body)) end |